@@ -251,10 +251,6 @@ if __name__ == "__main__":
 	pass
 else:
 	import os
-	if tf.__version__ == '2.2.0':
-		pass
-	else:
-		print("Tensorflow version mismatch. Error!")
 	from random import shuffle
 	import glob
 	import sys
